@@ -74,6 +74,10 @@ logging_cli_opts = [
                     + _IGNORE_MESSAGE),
     cfg.BoolOpt('watch-log-file',
                 default=False,
+                deprecated_for_removal=True,
+                deprecated_reason=('This function is known to have bene '
+                                   'broken for long time, and depends on '
+                                   'the unmaintained library'),
                 help='Uses logging handler designed to watch file '
                      'system. When log file is moved or removed this handler '
                      'will open a new log file with specified path '
@@ -111,7 +115,14 @@ generic_log_opts = [
                      + _IGNORE_MESSAGE),
     cfg.BoolOpt('use_eventlog',
                 default=False,
+                deprecated_for_removal=True,
+                deprecated_reason='Windows support is no longer maintained.',
                 help='Log output to Windows Event Log.'),
+    cfg.BoolOpt('log_color',
+                default=False,
+                help='(Optional) Set the \'color\' key according to log '
+                     'levels. This option takes effect only when logging '
+                     'to stderr or stdout is used. ' + _IGNORE_MESSAGE),
     cfg.IntOpt('log_rotate_interval',
                default=1,
                help='The amount of time before the log files are rotated. '
@@ -201,8 +212,8 @@ log_opts = [
                     'rate_limit_interval.'),
     cfg.StrOpt('rate_limit_except_level',
                default='CRITICAL',
-               help='Log level name used by rate limiting: CRITICAL, ERROR, '
-                    'INFO, WARNING, DEBUG or empty string. Logs with level '
+               choices=['CRITICAL', 'ERROR', 'INFO', 'WARNING', 'DEBUG', ''],
+               help='Log level name used by rate limiting. Logs with level '
                     'greater or equal to rate_limit_except_level are not '
                     'filtered. An empty string means that all levels are '
                     'filtered.'),
